#ifndef FACEBOOKWIDGET_H
#define FACEBOOKWIDGET_H

#include <QWidget>
#include <QWebView>
#include <QMouseEvent>
#include <QPoint>
#include <QSystemTrayIcon>
#include <QAction>
#include <QMenu>
#include "CookieJar.h"
#include "AboutWindow.h"
#include "Audio.h"


namespace Ui {
class FacebookWidget;
}

class FacebookWidget : public QWidget
{
    Q_OBJECT
    
public:
    explicit FacebookWidget(QWidget *parent = 0);
    ~FacebookWidget();

    
private:
    bool pressed;
    QPoint lastPos;
    Ui::FacebookWidget *ui;
    QWebView *webView;
    QSystemTrayIcon *systemTrayIcon;
    bool mousePress(const QPoint &value);
         void mouseMove(const QPoint &value);
         void mouseRelease(const QPoint &value);
    QMenu *systemTrayMenu;
    QAction *googleAction;
    QAction *facebookAction;
    QAction *twitterAction;
    QAction *quitAction;
    QAction *likeAction;
    QAction *supportAction;
    QAction *spendAction;

    QAction *windowVisibilityToggleAction;
    bool windowVisible;
    CookieJar *cookieJar;
    AboutWindow *aboutWindow;
    Audio *audio;

private slots:

    void onSystemTrayClicked(QSystemTrayIcon::ActivationReason reason);
    void twitterActionTriggered();
    void likeActionTriggered();
    void supportActionTriggered();
    void googleActionTriggered();
    void facebookActionTriggered();
    void toggleWindowVisibility();
    void spendActionTriggered();
    void quitActionTriggered();
    void on_msgButton_clicked();
    void on_newsButton_clicked();
    void on_myButton_clicked();

    void on_chatButton_clicked();
    void on_eventButton_clicked();
    void on_likeButton_clicked();

    void on_gButton_clicked();

    void on_webButton_clicked();

    void on_fButton_clicked();
    void on_tButton_clicked();
    void on_ppButton_clicked();
protected:
    void mousePressEvent(QMouseEvent *event);
    void mouseMoveEvent(QMouseEvent *);

};

#endif // FACEBOOKWIDGET_H
